/***************************************************************************
                          rlayer.cpp  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/


/****************************************************************************
** rlayer.cpp 1998/09/05 A. Mustun RibbonSoft
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#include "rlayer.h"

// Constructor:
//
RLayer::RLayer()
{
  name="";
  number=-1;
  color=Qt::black;
  width=0;
  style=Qt::SolidLine;
}



// Destructor:
//
RLayer::~RLayer()
{
}


// EOF


